@@ -10,6 +10,7 @@ from blueflask.lib.errors import unauthorized
 
 from ....consts import SERVICE_CODE
 
+
 api = Blueprint('api', __name__)
 
 __version__ = '1.0'
@@ -49,16 +50,18 @@ def method_not_allowed_error(e):
 
 @api.errorhandler(500)
 def internal_server_error(e):
-    msg = 'Please contact API maintainers'
+    message = (
+        'une erreur interne est survenue; '
+        'veuillez contacter support_n1@si.blueline.mg'
+        )
     return internal_error(
-        msg,
+        message,
         request_id=request.headers.get('X-Request-Id'),
         service_code=SERVICE_CODE
         )
 
 from . import docs  # NOQA
 from . import registry  # NOQA
-from . import requests  # NOQA
 from . import gateway  # NOQA
 
 
